@@ -16,7 +16,7 @@ __all__ = (
     'ZeroDivisionErrorOperand', 'SimpleOperand', 'SingleCellOperand',
     'CellSetOperand', 'SimpleSetOperand', 'NamedRangeOperand', 'CellRangeOperand',
     'FunctionNotSupported', 'NotFoundErrorOperand', 'RPNOperand', 'OperandLikeObject', 'OffsetMixin',
-    'SetOperand', 'BadReference', 'ValueNotAvailable',
+    'SetOperand', 'BadReference', 'ValueNotAvailable', 'EmptyOperand',
 )
 
 
@@ -70,6 +70,10 @@ class Operand(OperandLikeObject):
         return self.__int__()
 
 
+class EmptyOperand(OperandLikeObject):
+    pass
+
+
 class ErrorOperand(OperandLikeObject, BaseEFCException):
     code = 300
     msg = 'Unknown error'
